==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebActionStripDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActionStripResourceStringsDescriptionMetadata } from "./WebActionStripResourceStringsDescriptionMetadata";
import { WebDisplayDensityBaseElementDescriptionMetadata } from "./WebDisplayDensityBaseElementDescriptionMetadata";
import { WebActionStripDescription } from "./WebActionStripDescription";
/**
 * @hidden
 */
var WebActionStripDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebActionStripDescriptionMetadata, _super);
    function WebActionStripDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActionStripDescriptionMetadata.b = function (a) {
        if (WebActionStripDescriptionMetadata.a == null) {
            WebActionStripDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActionStripDescriptionMetadata.c(WebActionStripDescriptionMetadata.a);
        }
        if (a.j(WebActionStripDescriptionMetadata.a)) {
            return;
        }
        a.y(WebActionStripDescriptionMetadata.a);
        WebActionStripResourceStringsDescriptionMetadata.d(a);
    };
    WebActionStripDescriptionMetadata.c = function (a) {
        WebDisplayDensityBaseElementDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ActionStrip");
        a.item("__tagNameWC", "String:igc-action-strip");
        a.item("__packageNameWC", "String:grids");
        a.item("__manageItemInMarkup", "Boolean");
        a.item("Context", "Unknown");
        a.item("ActionButtons", "Collection:WebGridActionsBaseDirective:GridActionsBaseDirectiveCollection:WebGridActionsBaseDirective");
        a.item("Hidden", "Boolean");
        a.item("ResourceStrings", "ExportedType:WebActionStripResourceStrings");
        a.item("Name", "String");
    };
    WebActionStripDescriptionMetadata.d = function (a) {
        WebActionStripDescriptionMetadata.b(a);
        a.aa("WebActionStrip", function () { return new WebActionStripDescription(); });
        a.z("WebActionStrip", WebActionStripDescriptionMetadata.a);
    };
    WebActionStripDescriptionMetadata.$t = markType(WebActionStripDescriptionMetadata, 'WebActionStripDescriptionMetadata');
    WebActionStripDescriptionMetadata.a = null;
    return WebActionStripDescriptionMetadata;
}(Base));
export { WebActionStripDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebActionStripDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActionStripResourceStringsDescriptionMetadata } from "./WebActionStripResourceStringsDescriptionMetadata";
import { WebDisplayDensityBaseElementDescriptionMetadata } from "./WebDisplayDensityBaseElementDescriptionMetadata";
import { WebActionStripDescription } from "./WebActionStripDescription";
/**
 * @hidden
 */
var WebActionStripDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebActionStripDescriptionMetadata, _super);
    function WebActionStripDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActionStripDescriptionMetadata.b = function (a) {
        if (WebActionStripDescriptionMetadata.a == null) {
            WebActionStripDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActionStripDescriptionMetadata.c(WebActionStripDescriptionMetadata.a);
        }
        if (a.k(WebActionStripDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebActionStripDescriptionMetadata.a);
        WebActionStripResourceStringsDescriptionMetadata.d(a);
    };
    WebActionStripDescriptionMetadata.c = function (a) {
        WebDisplayDensityBaseElementDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ActionStrip");
        a.item("__tagNameWC", "String:igc-action-strip");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__manageItemInMarkup", "Boolean");
        a.item("Context", "Unknown");
        a.item("ActionButtons", "Collection:WebGridActionsBaseDirective:GridActionsBaseDirectiveCollection:WebGridActionsBaseDirective");
        a.item("Hidden", "Boolean");
        a.item("ResourceStrings", "ExportedType:WebActionStripResourceStrings");
        a.item("Name", "String");
    };
    WebActionStripDescriptionMetadata.d = function (a) {
        WebActionStripDescriptionMetadata.b(a);
        a.ac("WebActionStrip", function () { return new WebActionStripDescription(); });
        a.ab("WebActionStrip", WebActionStripDescriptionMetadata.a);
    };
    WebActionStripDescriptionMetadata.$t = markType(WebActionStripDescriptionMetadata, 'WebActionStripDescriptionMetadata');
    WebActionStripDescriptionMetadata.a = null;
    return WebActionStripDescriptionMetadata;
}(Base));
export { WebActionStripDescriptionMetadata };
